==> svm-1.0.0-rc14-sources.jar: com/oracle/svm/hosted/JCKRuntimeTestsSupportFeature.java <==
/*
 * Copyright (c) 2019, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.hosted;

import org.graalvm.nativeimage.Feature;
import org.graalvm.nativeimage.Platform;
import org.graalvm.nativeimage.Platforms;
import org.graalvm.nativeimage.RuntimeReflection;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;

/**
 * JCK Runtime tests reflectively access public methods of main class.
 */
@Platforms(Platform.HOSTED_ONLY.class)
public class JCKRuntimeTestsSupportFeature implements Feature {
    @Override
    public void beforeAnalysis(BeforeAnalysisAccess config) {
        Class<?> mainClass = config.findClassByName(NativeImageOptions.Class.getValue());
        for (Method method : mainClass.getDeclaredMethods()) {
            if (Modifier.isPublic(method.getModifiers())) {
                RuntimeReflection.register(method);
            }
        }
    }
}

==> svm-19.0.0-sources.jar: com/oracle/svm/hosted/JCKRuntimeTestsSupportFeature.java <==
/*
 * Copyright (c) 2019, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package com.oracle.svm.hosted;

import org.graalvm.nativeimage.hosted.Feature;
import org.graalvm.nativeimage.Platform;
import org.graalvm.nativeimage.Platforms;
import org.graalvm.nativeimage.hosted.RuntimeReflection;

import java.lang.reflect.Method;
import java.lang.reflect.Modifier;

/**
 * JCK Runtime tests reflectively access public methods of main class.
 */
@Platforms(Platform.HOSTED_ONLY.class)
public class JCKRuntimeTestsSupportFeature implements Feature {
    @Override
    public void beforeAnalysis(BeforeAnalysisAccess config) {
        Class<?> mainClass = config.findClassByName(NativeImageOptions.Class.getValue());
        for (Method method : mainClass.getDeclaredMethods()) {
            if (Modifier.isPublic(method.getModifiers())) {
                RuntimeReflection.register(method);
            }
        }
    }
}
